@@ -18,7 +18,6 @@
 #include "qwaylandplatformservices_p.h"
 #include "qwaylandscreen_p.h"
 #include "qwaylandcursor_p.h"
-#include "qwaylandeventdispatcher_p.h"
 
 #if defined(Q_OS_MACOS)
 #  include <QtGui/private/qcoretextfontdatabase_p.h>
@@ -26,6 +25,7 @@
 #else
 #  include <QtGui/private/qgenericunixfontdatabase_p.h>
 #endif
+#include <QtGui/private/qgenericunixeventdispatcher_p.h>
 #include <QtGui/private/qgenericunixtheme_p.h>
 
 #include <QtGui/private/qguiapplication_p.h>
@@ -173,7 +173,7 @@ QPlatformBackingStore *QWaylandIntegration::createPlatformBackingStore(QWindow *
 
 QAbstractEventDispatcher *QWaylandIntegration::createEventDispatcher() const
 {
-    return QWaylandEventDispatcher::createEventDispatcher();
+    return createUnixEventDispatcher();
 }
 
 QPlatformNativeInterface *QWaylandIntegration::createPlatformNativeInterface()
